try:
    from django.conf.urls import url as re_path # Django 1.11
except ImportError:
    from django.urls import re_path

from . import views as FollowitViews

urlpatterns = [
    re_path(
        r'^follow/(?P<model_name>\w+)/(?P<object_id>\d+)/$',
        FollowitViews.follow_object,
        name = 'follow_object'
    ),
    re_path(
        r'^unfollow/(?P<model_name>\w+)/(?P<object_id>\d+)/$',
        FollowitViews.unfollow_object,
        name = 'unfollow_object'
    ),
    re_path(
        r'^toggle-follow/(?P<model_name>\w+)/(?P<object_id>\d+)/$',
        FollowitViews.toggle_follow_object,
        name='toggle_follow_object'
    )
]



from setuptools import setup, find_packages
import ez_setup
ez_setup.use_setuptools()

setup(
    name="django-followit",
    version='0.6.0',
    description='A Django application that allows users to follow django model objects',
    packages=find_packages(),
    author='Evgeny.Fadeev',
    author_email='evgeny.fadeev@gmail.com',
    license='BSD License',
    keywords='follow, database, django',
    url='https://github.com/ASKBOT/django-followit',
    include_package_data=True,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: JavaScript',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
    ],
    long_description=''.join(open('README.rst', 'r').readlines()[4:]),
    long_description_content_type='text/x-rst'
)
